/*
 *  Copyright (C) 2011 Joos Kiener
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.

 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bitbucket.kienerj.moleculedatabaseframework.chemistry;

import org.bitbucket.kienerj.moleculedatabaseframework.MoleculeDatabaseFrameworkException;

/**
 * RuntimeException to wrap a CDKException that occurs during creation of a
 * Molecule from String / Textual data.
 *
 * @author Joos Kiener
 */
public class FormatConversionException extends MoleculeDatabaseFrameworkException{

    private String structureData;

    /**
     *
     *
     * @param cause
     * @param structureData the data that caused the exception
     */
    public FormatConversionException(Throwable cause, String structureData){
        super(cause);
        this.structureData = structureData;
    }
    /**
     *
     * @param message
     * @param structureData the data that caused the exception
     */
    public FormatConversionException(String message, String structureData){
        super(message);
        this.structureData = structureData;
    }

    public FormatConversionException(Throwable cause){
        super(cause);
    }

    /**
     * @return the structure data causing the issue
     */
    public String getStructureData() {
        return structureData;
    }
}
