/*
 *  Copyright (C) 2012 Joos Kiener <Joos.Kiener@gmail.com>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.

 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bitbucket.kienerj.moleculedatabaseframework.repository;

import java.util.List;
import org.bitbucket.kienerj.moleculedatabaseframework.entity.ChemicalCompound;
import org.bitbucket.kienerj.moleculedatabaseframework.entity.ChemicalCompoundContainer;
import org.bitbucket.kienerj.moleculedatabaseframework.entity.ChemicalStructure;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 * Spring Data Repository for <code>ChemicalCompoundContainer</code> implementation.
 * </p>
 *
 * @author Joos Kiener <Joos.Kiener@gmail.com>
 */
@Transactional(propagation = Propagation.MANDATORY)
@Repository
public interface CompoundContainerRepository<T extends ChemicalCompoundContainer>
        extends ChemicalStructureSearchRepository<T>, IdRepository<T>,
        BaseEntityRepository<T> {

    /**
     * Find all containers containing <code> compound</code>
     *
     * @param compound
     * @return
     */
    List<T> findByContainableChemicalCompound(ChemicalCompound compound);

    /**
     * Find all containers that contain the compound with CAS Number <code>cas</code>.
     *
     * @param cas
     * @return
     */
    List<T> findByContainableChemicalCompoundCas(String cas);

    @Query("select c from ChemicalCompoundContainer c join c.containable containable"
            + " join containable.chemicalCompound compound join compound.compositions"
            + " comp where comp.pk.chemicalStructure = ?1")
    List<T> findByChemicalStructureEntity(ChemicalStructure structure);

}
