/*
 * Copyright (C) 2013 Joos Kiener <Joos.Kiener@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bitbucket.kienerj.moleculedatabaseframework.security;

import java.util.Collection;
import lombok.Data;
import org.bitbucket.kienerj.moleculedatabaseframework.entity.BaseEntity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.hierarchicalroles.RoleHierarchy;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

/**
 * <p>
 * Basic implementation of <code>Permission</code>.
 * </p>
 * <p>
 * See {@link org.bitbucket.kienerj.moleculedatabaseframework.security.Permission}
 * for further information.
 * </p>
 *
 * @author Joos Kiener <Joos.Kiener@gmail.com>
 */
@Data
public abstract class AbstractPermission implements Permission {

    @Autowired
    private RoleHierarchy roleHierarchy;
    private final String targetType;


    public AbstractPermission(String targetType){
        this.targetType = targetType;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public abstract boolean isAllowed(Authentication authentication,
        Object targetDomainObject, String permissionType, String permissionTarget);

    
    protected boolean hasRole(final Authentication authentication,
            final String role) {
        final Collection<? extends GrantedAuthority> authorities =
                roleHierarchy.getReachableGrantedAuthorities(authentication.getAuthorities());
        for (GrantedAuthority authoritiy : authorities) {
            if (authoritiy.getAuthority().equals(role)) {
                return true;
            }
        }
        return false;
    }


    protected boolean isCreator(final Authentication authentication,
            final Object targetDomainObject) {

        final String userName = getLogin(authentication);
        return ((BaseEntity) targetDomainObject).getCreatedBy().equals(userName);
    }

    protected String getLogin(Authentication authentication) {
        Object authenticationUserDetails = authentication.getPrincipal();
        return ((UserDetails) authenticationUserDetails).getUsername();
    }

    protected boolean isAuthenticated(final Authentication authentication) {
        return authentication != null && authentication.getPrincipal() instanceof UserDetails;
    }
}
