/*
 * Copyright (C) 2013 Joos Kiener <Joos.Kiener@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bitbucket.kienerj.moleculedatabaseframework.security;

import org.springframework.security.core.Authentication;

/**
 * <p>
 * A <code>Permission</code> verifies if a given user (<code>authentication</code>)
 * can perform the given action (<code>permissionType</code>) on the given entity
 * (<code>targetDomainObject</code>) that has a simple class name of <code>permissionTarget</code>.
 * </p>
 *
 * @author Joos Kiener <Joos.Kiener@gmail.com>
 */
public interface Permission {

    /**
     *
     * <p>
     * Verifies if a given user (<code>authentication</code>)
     * can perform the given action (<code>permissionType</code>) on the given entity
     * (<code>targetDomainObject</code>) that has a simple class name of <code>permissionTarget</code>.
     * </p>
     *
     * @param authentication a valid User
     * @param targetDomainObject the entity (domain object) an action is performed on
     * @param permissionType the type of action like "save" or "delete"
     * @param permissionTarget the simple class name of <code>targetDomainObject</code>
     * @return
     */
    boolean isAllowed(Authentication authentication, Object targetDomainObject, String permissionType, String permissionTarget);
}
