/*
 * Copyright (C) 2013 Joos Kiener <Joos.Kiener@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bitbucket.kienerj.moleculedatabaseframework.service;

import com.mysema.query.types.OrderSpecifier;
import com.mysema.query.types.Predicate;
import org.bitbucket.kienerj.moleculedatabaseframework.entity.Role;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;

/**
 *
 * @author Joos Kiener <Joos.Kiener@gmail.com>
 */
@Transactional(readOnly=true)
public interface RoleService extends Service<Role> {

    @PreAuthorize("hasRole('read_Role')")
    Role findByRoleName(String roleName);

    @PreAuthorize("hasRole('read_Role')")
    Role findOne(Predicate predicate);

    @PreAuthorize("hasRole('read_Role')")
    Iterable<Role>  findAll(Predicate predicate);

    @PreAuthorize("hasRole('read_Role')")
    Iterable<Role>  findAll(Predicate predicate, OrderSpecifier<?>... orders);

    @PreAuthorize("hasRole('read_Role')")
    Page<Role>  findAll(Predicate predicate, Pageable pageable);

    @Transactional(readOnly = false)
    @PreAuthorize("hasRole('manage_Role')")
    @Override
    Role save(Role role);

    @Transactional(readOnly = false)
    @PreAuthorize("hasRole('manage_Role')")
    void delete (Role role);

}
